pub async fn handle_crate_request_watch<B>(
req: Request<B>,
static_: Static,
crate_name: String,
build_id: Arc<AtomicU64>,
) -> Result<Response<BoxBody<Bytes, Error>>, Error>Expand description
handle crate doc request in watch mode.
Responds to /_buildid with the current build counter so the injected
JavaScript can detect when a rebuild has completed and reload the page.
HTML responses have RELOAD_SCRIPT injected before </body>.